@@ -10,6 +10,20 @@ import regex
 from enum import Enum
 
 
+class MessageContainer:
+    def __init__(
+        self,
+        channel: pika.channel.Channel,
+        basic_deliver: pika.spec.Basic.Deliver,
+        properties: pika.spec.BasicProperties,
+        body: bytes,
+    ):
+        self.channel: pika.channel.Channel = channel
+        self.basic_deliver: pika.spec.Basic.Deliver = basic_deliver
+        self.properties: pika.spec.BasicProperties = properties
+        self.body: bytes = body
+
+
 class MessageHandlerError(RuntimeError):
     def __init__(self, message):
         super().__init__(message)
@@ -39,7 +53,7 @@ class AsyncConsumerBase(Loggable):
         self,
         amqp_url: str,
         queue: str,
-        message_handler: Callable[[bytes], None],
+        message_handler: Callable[[MessageContainer], None],
         durable: bool = False,
         exchange: str = "",
         exchange_type: Optional[ExchangeType] = None,
@@ -340,13 +354,13 @@ class AsyncConsumerBase(Loggable):
         if self._channel:
             self._channel.close()
 
-    def handle_message(self, body: bytes):
+    def handle_message(self, message: MessageContainer):
         if self._message_handler is not None:
-            self._message_handler(body)
+            self._message_handler(message)
 
     def on_message(
         self,
-        _unused_channel: pika.channel.Channel,
+        channel: pika.channel.Channel,
         basic_deliver: pika.spec.Basic.Deliver,
         properties: pika.spec.BasicProperties,
         body: bytes,
@@ -358,7 +372,7 @@ class AsyncConsumerBase(Loggable):
         instance of BasicProperties with the message properties and the body
         is the message that was sent.
 
-        :param pika.channel.Channel _unused_channel: The channel object
+        :param pika.channel.Channel channel: The channel object
         :param pika.Spec.Basic.Deliver basic_deliver: method
         :param pika.Spec.BasicProperties properties: properties
         :param bytes body: The message body
@@ -368,7 +382,9 @@ class AsyncConsumerBase(Loggable):
             f"Received message # {basic_deliver.delivery_tag} from {properties.app_id}"
         )
         try:
-            self.handle_message(body)
+            self.handle_message(
+                MessageContainer(channel, basic_deliver, properties, body)
+            )
             self.acknowledge_message(basic_deliver.delivery_tag)
         except MessageHandlerError:
             if self._handler_exception_behavior == ExceptionHandlingBehavior.NACK:
@@ -480,7 +496,7 @@ class ReconnectingConsumer(Loggable):
         self,
         amqp_url: str,
         queue: str,
-        message_handler: Callable[[bytes], None],
+        message_handler: Callable[[MessageContainer], None],
         durable: bool = False,
         exchange: str = "",
         exchange_type: Optional[ExchangeType] = None,
@@ -538,7 +554,7 @@ class LocalRaspiSqaTestResultConsumer(ReconnectingConsumer):
     def __init__(
         self,
         hostname: str,
-        message_handler: Callable[[bytes], None],
+        message_handler: Callable[[MessageContainer], None],
         username: str = None,
         password: str = None,
     ):
