@@ -19,10 +19,10 @@ MESSAGE_QUEUE_SIZE_LIMIT = 67108864  # 64MB
 
 class UbaiArtifactUploadRequestProducer:
     def __init__(self, url=None, producer_app_id: str = None):
-        self.queue_name = "ubai_artifact_request"
+        self.queue_name = "default"
         self.__client = BlockingProducer(url, producer_app_id)
-        # No need to declare queue. It will already exist
-        #self.__client.queue_declare(queue=self.queue_name, durable=True)
+        self.__client.queue_declare(queue=self.queue_name, durable=True)
+        self.producer_app_id = producer_app_id
 
     def upload_artifact(
         self, artifact_file: str, metadata: dict, validate_metadata: bool=True
@@ -67,7 +67,8 @@ class UbaiArtifactUploadRequestProducer:
         queue_message = QueueMessage(
             payload=artifact_request,
             recordType="ARTIFACT_UPLOAD_REQUEST",
-            timestamp=datetime.now().timestamp(),
+            tenantKey=self.producer_app_id,
+            recordTimestamp=datetime.now().isoformat(),
         )
         queue_message.validate_schema()
 
