@@ -18,25 +18,29 @@ from typing import Iterable, Tuple
 @click.option("--metadata", multiple=True, type=(str, str))
 @click.option(
     "--username",
-    envvar='UTF_QUEUE_USERNAME',
+    envvar="UTF_QUEUE_USERNAME",
     help="UTF queue username",
 )
 @click.option(
     "--password",
-    envvar='UTF_QUEUE_PASSWORD',
+    envvar="UTF_QUEUE_PASSWORD",
     help="UTF queue password",
 )
 @click.option(
     "--client-id", type=str, default="Unknown Client", help="Optional client identifier"
 )
+@click.option(
+    "--retries", default=3, help="number of retries (in case of network-related issues)"
+)
 def cli_entrypoint(
     file_path: str,
     metadata: Iterable[Tuple[str, str]],
     username: str,
     password: str,
     client_id: str,
+    retries: int,
 ):
-    cli(file_path, metadata, username, password, client_id)
+    cli(file_path, metadata, username, password, client_id, retries)
 
 
 def cli(
@@ -45,13 +49,26 @@ def cli(
     username: str,
     password: str,
     client_id: str,
+    retries: int = 3,
 ):
+    if username is None or password is None:
+        raise RuntimeError("username or password must be provided")
     hostname = os.environ.get("UTF_QUEUE_HOSTNAME", "utf-queue-central.silabs.net")
+    scheme = os.environ.get("UTF_QUEUE_SCHEME", "amqps")
+    port = os.environ.get("UTF_QUEUE_PORT", "443")
+    virtual_host = os.environ.get("UTF_QUEUE_VIRTUAL_HOST", "%2f")
+    url = f"{scheme}://{username}:{parse.quote(password)}@{hostname}:{port}/{virtual_host}"
 
-    url = f"amqps://{username}:{parse.quote(password)}@{hostname}:443"
-
-    client = UbaiArtifactUploadRequestProducer(url, client_id)
     metadata_dict = {}
     for key, value in metadata:
         metadata_dict[key] = value
-    client.upload_artifact(file_path, metadata=metadata_dict)
+
+    total_attempts = retries + 1
+    for try_index in range(total_attempts):
+        try:
+            client = UbaiArtifactUploadRequestProducer(url, client_id)
+            client.upload_artifact(file_path, metadata=metadata_dict)
+            break
+        except Exception:
+            if (try_index + 1) >= total_attempts:
+                raise
